pub enum ModelChoice {
Message(String),
ToolCall(Vec<ToolCall>),
}Expand description
The model’s choice of response for a single completion turn.
Variants
Message(String)
The model produced a text reply.
ToolCall(Vec<ToolCall>)
The model wants to call one or more tools.