EmbeddingsBuilder

Struct EmbeddingsBuilder 

pub struct EmbeddingsBuilder<M, T> { /* private fields */ }
Accumulates documents, embeds them in efficient batches, and returns each document paired with its embedding(s).

Implementations

Source

impl<M: EmbeddingModel, T: Embed> EmbeddingsBuilder<M, T>

pub fn new(model: M) -> Self

pub fn document(self, doc: T) -> Result<Self, EmbedError>

Add a single document.

pub fn documents( self, docs: impl IntoIterator<Item = T>, ) -> Result<Self, EmbedError>

Add multiple documents.

pub async fn build(self) -> Result<Vec<(T, Vec<Embedding>)>, EmbeddingError>

Embed all queued documents.

Returns Vec<(T, Vec<Embedding>)>. Each Vec<Embedding> has one entry per text the document pushed via Embed::embed — same order.