Tool

Trait Tool 

pub trait Tool {
    type Error: Error + 'static;
    type Args: DeserializeOwned;
    type Output: Serialize;

    const NAME: &'static str;

    // Required methods
    fn definition(&self) -> ToolDefinition;
    fn call(
        &self,
        args: Self::Args,
    ) -> impl Future<Output = Result<Self::Output, Self::Error>>;
}
A typed, async tool that an Agent can call.

Implement this trait to create tools. Register them with a ToolSet.

Required Associated Constants

const NAME: &'static str

Must match ToolDefinition::name exactly.

Required Associated Types

type Error: Error + 'static

Error type returned if the tool fails.

type Args: DeserializeOwned

Deserialised argument type. Must match the parameters schema.

type Output: Serialize

Serialisable output type.

Required Methods

fn definition(&self) -> ToolDefinition

Schema + description sent to the model before each completion call.

fn call( &self, args: Self::Args, ) -> impl Future<Output = Result<Self::Output, Self::Error>>

Execute the tool with the deserialised arguments.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors